# Xumes

Xumes is a game testing tool designed to be used on top of games without the need to modify the game sources. It provides a framework for observing and interacting with game elements, training models, and conducting tests. For the moment, only the Godot framework has an implemented module for interacting with Xumes. So for the moment, the documentation will be focus on the implementation with godot.

<!--- Please check the [documentation](https://xumes.readthedocs.io/en/latest/) for more information. --->

## Framework usage

The framework is based on the BDD methodology, that's means that two type of files are needed to be write for conducting tests. Those file are the `feature` files and the `steps` files.

The following diagram illustrates the architecture of the framework:

![framework schema](https://github.com/mastainvin/Xumes/assets/61213519/7eadf335-4e8d-4797-9d83-98304a78f275)


## Installation

TODO
